pub fn compute_snapshot_content_hash(bytes: &[u8]) -> StringExpand description
Computes the default cache snapshot content hash recorded in a SnapshotAnchor.
pub fn compute_snapshot_content_hash(bytes: &[u8]) -> StringComputes the default cache snapshot content hash recorded in a SnapshotAnchor.